==> ikaaro-0.50.0.tar.gz: ikaaro-0.50.0/ui/tiny_mce/plugins/advlink/langs/fr_dlg.js <==
tinyMCE.addI18n('fr.advlink_dlg',{
title:"Ins\u00E9rer/\u00C9diter lien",
url:"URL du lien",
target:"Cible",
titlefield:"Titre",
is_email:"L'url que vous avez entr\u00E9 semble \u00EAtre une adresse e-mail, voulez-vous ajouter le pr\u00E9fixe mailto:\u00A0?",
is_external:"L'url que vous avez entr\u00E9 semble \u00EAtre une adresse web externe, voulez-vous ajouter le pr\u00E9fixe http://\u00A0?",
list:"Liste de liens",
general_tab:"G\u00E9n\u00E9ral",
popup_tab:"Popup",
events_tab:"\u00C9v\u00E9nements",
advanced_tab:"Advanc\u00E9",
general_props:"Propri\u00E9t\u00E9s g\u00E9n\u00E9rales",
popup_props:"Propri\u00E9t\u00E9s du popup",
event_props:"\u00C9v\u00E9nements",
advanced_props:"Propri\u00E9t\u00E9s avanc\u00E9es",
popup_opts:"Options",
anchor_names:"Ancres",
target_same:"Ouvrir dans cette fen\u00EAtre / dans ce cadre",
target_parent:"Ouvrir dans la fen\u00EAtre / le cadre parent",
target_top:"Ouvrir dans le cadre principal (Remplace tous les cadres)",
target_blank:"Ouvrir dans une nouvelle fen\u00EAtre",
popup:"Popup en Javascript",
popup_url:"URL du popup",
popup_name:"Nom de la fen\u00EAtre",
popup_return:"Ins\u00E9rer 'return false'",
popup_scrollbars:"Afficher les ascenseurs",
popup_statusbar:"Afficher la barre de status",
popup_toolbar:"Afficher la barre d'outils",
popup_menubar:"Afficher la barre de menu",
popup_location:"Afficher la barre d'adresse",
popup_resizable:"Rendre la fen\u00EAtre redimensionable",
popup_dependent:"D\u00E9pendent (Seulement sous Mozilla/Firefox)",
popup_size:"Taille",
popup_position:"Position (X/Y)",
id:"Id",
style:"Style",
classes:"Classes",
target_name:"Nom de la cible",
langdir:"Sens de lecture",
target_langcode:"Langue de la cible",
langcode:"Code de la langue",
encoding:"Encodage de la cible",
mime:"Type MIME de la cible",
rel:"Relation de la page \u00E0 la cible",
rev:"Relation de la cible \u00E0 la page",
tabindex:"Tabindex",
accesskey:"Touche d'acc\u00E8s rapide",
ltr:"Gauche \u00E0 droite",
rtl:"Droite \u00E0 gauche",
link_list:"Liste des liens"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/plugins/advlink/langs/fr_dlg.js <==
tinyMCE.addI18n('fr.advlink_dlg',{
title:"Ins\u00E9rer / \u00E9diter un lien",
url:"URL du lien",
target:"Cible",
titlefield:"Titre",
is_email:"L'URL que vous avez saisie semble \u00EAtre une adresse e-mail, souhaitez-vous ajouter le pr\u00E9fixe \u00AB mailto: \u00BB ?",
is_external:"L'URL que vous avez saisie semble \u00EAtre une adresse web externe. Souhaitez-vous ajouter le pr\u00E9fixe \u00AB http:// \u00BB ?",
list:"Liste de liens",
general_tab:"G\u00E9n\u00E9ral",
popup_tab:"Popup",
events_tab:"\u00C9v\u00E8nements",
advanced_tab:"Avanc\u00E9",
general_props:"Propri\u00E9t\u00E9s g\u00E9n\u00E9rales",
popup_props:"Propri\u00E9t\u00E9s de la popup",
event_props:"\u00C9v\u00E8nements",
advanced_props:"Propri\u00E9t\u00E9s avanc\u00E9es",
popup_opts:"Options",
anchor_names:"Ancres",
target_same:"Ouvrir dans cette fen\u00EAtre / dans ce cadre",
target_parent:"Ouvrir dans la fen\u00EAtre / le cadre parent",
target_top:"Ouvrir dans le cadre principal (remplace tous les cadres)",
target_blank:"Ouvrir dans une nouvelle fen\u00EAtre",
popup:"Popup Javascript",
popup_url:"URL de la popup",
popup_name:"Nom de la fen\u00EAtre",
popup_return:"Ins\u00E9rer 'return false'",
popup_scrollbars:"Afficher les ascenseurs",
popup_statusbar:"Afficher la barre d'\u00E9tat",
popup_toolbar:"Afficher la barre d'outils",
popup_menubar:"Afficher la barre de menu",
popup_location:"Afficher la barre d'adresse",
popup_resizable:"Autoriser le redimensionnement de la fen\u00EAtre",
popup_dependent:"D\u00E9pendante (seulement sous Mozilla/Firefox)",
popup_size:"Taille",
popup_position:"Position (X/Y)",
id:"Id",
style:"Style",
classes:"Classes",
target_name:"Nom de la cible",
langdir:"Sens de lecture",
target_langcode:"Langue de la cible",
langcode:"Code de la langue",
encoding:"Encodage de la cible",
mime:"Type MIME de la cible",
rel:"Relation de la page \u00E0 la cible",
rev:"Relation de la cible \u00E0 la page",
tabindex:"Tabindex",
accesskey:"Touche d'acc\u00E8s rapide",
ltr:"Gauche \u00E0 droite",
rtl:"Droite \u00E0 gauche",
link_list:"Liste des liens"
});
